@@ -17,7 +17,7 @@
 import sys
 import socket
 from M2Crypto import RSA, X509, EVP, m2
-from calculate.core.datavars import DataVarsCore
+from ..datavars import DataVarsCore
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -49,7 +49,7 @@ def makeRequest(pubkey, pkey, serv_host, auto=False):
     if auto:
         c = 'n'
     else:
-        c = raw_input(_("Enter the certificate date manually? y/[n]: "))
+        c = input(_("Enter the certificate date manually? y/[n]: "))
     # Get HostName
     host_name = socket.getfqdn()
     list_host_name = host_name.split('.')
@@ -69,20 +69,20 @@ def makeRequest(pubkey, pkey, serv_host, auto=False):
         # list_host_name[len(list_host_name)-1]+"@"+serv_host
         # else:
         # host_name = socket.getfqdn()
-        _CN = raw_input(_('Hostname [%s] : ') % result_host_name)
+        _CN = input(_('Hostname [%s] : ') % result_host_name)
         name.CN = _CN or result_host_name or ""
 
-        _OU = raw_input(_('Username [%s]: ') % username)
+        _OU = input(_('Username [%s]: ') % username)
         name.OU = _OU or username or ""
 
-        _O = raw_input(_('Organization name: '))
+        _O = input(_('Organization name: '))
         name.O = _O or ""
-        _L = raw_input(_('Network address (hostname or IP) [%s]: ')
+        _L = input(_('Network address (hostname or IP) [%s]: ')
                            % host_name)
         name.L = _L or ""
-        _ST = raw_input(_('City: '))
+        _ST = input(_('City: '))
         name.ST = _ST or ""
-        _C = raw_input(_('Country: [%s]') % lang)
+        _C = input(_('Country: [%s]') % lang)
         name.C = _C or lang or "C"
     else:
         name.CN = result_host_name or ""  # Имя сертификата (Common Name);
