@@ -14,8 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+ 
 import sys
 from .function import get_sid
 
@@ -90,7 +90,7 @@ def gen_pid_ls(client, pid_ls):
 
 def client_pid_info(client):
     """ get information about selected process (or about all) """
-    pid = raw_input(_("PID") + _(": "))
+    pid = input(_("PID") + _(": "))
     try:
         pid = int(pid)
     except ValueError:
@@ -149,7 +149,7 @@ def client_list_sessions(client):
 
 def client_pid_kill(client):
     """ kill process on server """
-    pid = raw_input(_("PID to be killed: "))
+    pid = input(_("PID to be killed: "))
     try:
         pid = int(pid)
     except ValueError:
