@@ -272,7 +272,7 @@ def get_certificate_dn(cert_file):
         certobj = OpenSSL.crypto.load_certificate(
             OpenSSL.SSL.FILETYPE_PEM, cert_data)
         cert_info = dict(certobj.get_subject().get_components())
-        return cert_info["CN"]
+        return cert_info[b"CN"].decode("UTF-8")
     return "localhost"
 
 
@@ -403,8 +403,8 @@ def get_certificate(cert_path, data_path, certbase, client_cert_path,
                 OpenSSL.SSL.FILETYPE_PEM, ca_root)
             issuer = certobj.get_issuer().get_components()
             for item in issuer:
-                if item[0] == 'CN':
-                    filename = item[1]
+                if item[0] == b'CN':
+                    filename = item[1].decode("UTF-8")
 
             fc = open(root_cert_md5, "a")
             fc.write('%s %s\n' % (md5sum, filename))
