@@ -62,7 +62,7 @@ def serv_post_client_request(request, data_path,
         f.write(request)
 
     md5 = hashlib.md5()
-    md5.update(request)
+    md5.update(request.encode("UTF-8"))
     md5sum = md5.hexdigest()
     date = datetime.datetime.now()
 
@@ -95,7 +95,7 @@ def serv_get_client_cert(req_id, request, data_path, client_certbase,
     fp.close()
 
     md5 = hashlib.md5()
-    md5.update(cert)
+    md5.update(cert.encode("UTF-8"))
     md5sum = md5.hexdigest()
     date = datetime.datetime.now()
 
@@ -193,7 +193,7 @@ def serv_post_server_request(request, data_path,
         f.write(request)
 
     md5 = hashlib.md5()
-    md5.update(request)
+    md5.update(request.encode("UTF-8"))
     md5sum = md5.hexdigest()
     date = datetime.datetime.now()
 
@@ -227,7 +227,7 @@ def serv_get_server_request(req_id, request, data_path, serv_certbase,
     fp.close()
 
     md5 = hashlib.md5()
-    md5.update(cert)
+    md5.update(cert.encode("UTF-8"))
     md5sum = md5.hexdigest()
     date = datetime.datetime.now()
 
